clear all 

if c(username) == "maha9905"{
	qui cd "C:\Users\maha9905\Dropbox\PhD\TA\Political Economics II\2024\PS1\solutions\code "
}

* *GET DATA
* *Three variables we need to define. The footnote to the table have the relevant information:
* *
* *1) Trump’s vote share in the 2020 general election.
* *2) Difference between Trump’s vote share in the election and the average GOP vote share in presidential elections between 2000 and 2012.
* *This is a bit ambigious, one can think of three different ways:
* *i) Use average 2000-2012 again
* *ii) Use average 2000-2016
* *iii) Use average 2004-2016
* *Dont realy see a point why we should do iii)
* *3) Trump’s vote share in the GOP primaries.
* *There were not really any GOP Primary in 2020. According to Wikipedia Trump got 93.99% of the popular vote.
* *
* *In addition it would be nice to update the values on the other time varying variables:
* *a) median HH income
* *Appendix I tell us to get the data from American Community Surveys
* *b) unemployment
* *c) moral values.
* *This will be to hard to do...

import delimited "../input/countypres_2000-2020/countypres_2000-2020.csv", varn(1) clear 

drop if county_fips == "NA" // Missing value 
isid year county_fips party mode // Good practice to write out what is id in the data

* *We need to collapse away the mode variable

collapse (sum) candidatevotes (first) totalvotes, by(year county_fips party)

keep if party == "REPUBLICAN" | party == "DEMOCRAT"
gen _share_ = (candidatevotes / totalvotes) * 100
replace party = cond(party == "REPUBLICAN","gop","dem")
drop candidatevotes totalvotes

* *Reshape

reshape wide @_share_ , i(county_fips year) j(party) string
reshape wide dem_share_ gop_share_ , i(county_fips) j(year)

* *Altenative i)

egen diff_election_trump_ave_i = rowmean(gop_share_2000-gop_share_2012)
replace diff_election_trump_ave_i = gop_share_2020 - diff_election_trump_ave_i

* *Altenative ii)

egen diff_election_trump_ave_ii = rowmean(gop_share_2000-gop_share_2016)
replace diff_election_trump_ave_ii = gop_share_2020 - diff_election_trump_ave_ii

corr diff_election_trump_ave_ii diff_election_trump_ave_i // > 0.99 so does not seem to matter
drop diff_election_trump_ave_i
rename diff_election_trump_ave_ii diff_election_trump_ave

* *County FIPS is numeric in Enkes data

gen county = real(county_fips)

preserve  
    keep county diff_election_trump_ave gop_share_2020 dem_share_2020
    tempfile tmp1
    qui save `tmp1'
restore

* *Merge


rename (gop_share_????) (=_tmp)
merge 1:1 county using "../input/enke/County.dta"
tab _merge

* *So I learned that the analysis is only made on a subset 2,263 or 3,143 counties in the US
* *the 2) are Alaska

keep if _merge == 3
drop _merge

* *Look at the overlaping years and it seem to be alright with the exception of 2012

tw (scatter gop_share_2008*) (scatter gop_share_2012*) (scatter gop_share_2016*)

* *Which is more correct?
* *
* *
* *Unemployment

import delimited "../input/unemployment/ACSST5Y2019.S2301-Data.csv", varn(1) clear case(upper)
drop if _n == 1
gen county = real(substr(ÏGEO_ID,-5,.))
rename S2301_C04_001E unemp19 // From metadata table
keep county unemp19
destring unemp19, force replace 

tempfile tmp2
qui save `tmp2'

* *Median income

import delimited "../input/income/ACSCP5Y2019.CP03-Data.csv", varn(1) clear case(upper)
drop if _n == 1
gen county = real(substr(ÏGEO_ID,-5,.))
rename CP03_2019_062E inc19 // From metadata table (is it really right? What inflation adjustment should be done etc)
destring inc19, force replace 
gen ln_inc19 = log(inc19)
keep county ln_inc19

tempfile tmp3
qui save `tmp3'

* *Merge with existing

use "../input/enke/County.dta", clear

drop diff_election_trump_ave

forval i = 1/3{
    merge 1:1 county using `tmp`i'', nogen keep(1 3)
}

la var values_relative_shrink "Moral values"
la var ln_inc19 "Log (HH income)"
la var unemp19 "Unemployment rate"
la var ln_pd "Log(Population density)"


global county_base "ln_inc19 unemp19 racism_index_google ln_pd frac_religious abs_values_relative_shrink"
global geo "lat lon"

* *Table 6

eststo clear
eststo: qui reg gop_share_2020 values_relative_shrink i.state_id, ro
eststo: qui reg gop_share_2020 values_relative_shrink i.state_id $county_base $geo, ro
eststo: qui reg gop_share_2020 values_relative_shrink i.cz $county_base $geo, ro
eststo: qui reg gop_share_2020 values_relative_shrink i.cbsa $county_base $geo, ro
eststo: qui reg diff_election_trump_ave values_relative_shrink i.state_id, ro
eststo: qui reg diff_election_trump_ave values_relative_shrink i.state_id $county_base $geo, ro
eststo: qui reg diff_election_trump_ave values_relative_shrink i.cz $county_base $geo, ro
eststo: qui reg diff_election_trump_ave values_relative_shrink i.cbsa $county_base $geo, ro

local outdirs "`"C:\Users\maha9905\Dropbox\Apps\Overleaf/PS 1 - Political Economics II/"'" "`"../output/"'"

foreach od of local outdirs{
#delimit ;
    esttab using "`od'4c.tex", 
        booktabs 
        nonotes 
        replace 
        compress  
        label 
        nomtitles 
        indicate("State FE=*state_id*" "Commuting zone FE=*cz*" "CBSA FE=*cbsa*")  
        drop(_cons) 
        se(2) 
        b(a2) 
        r2(2)  
        star(* 0.10 ** 0.05 *** 0.01) 
        prehead("{
                \begin{tabular}{l*{8}{c}}
                \toprule\toprule 
                & \multicolumn{8}{c} {\textit{Dependent variable:}} \\[.1cm]  
                & \multicolumn{8}{c}{Vote shares} \\ \cmidrule(lr){2-9}
                & \multicolumn{8}{c}{Presidential election} \\ \cmidrule(lr){2-9}
                & \multicolumn{4}{c}{Trump} \multicolumn{4}{c}{$\Delta$ [Trump -- Ave. GOP]} \\ \cmidrule(lr){2-5} \cmidrule(lr){6-9} 
                "  
        )
        ;
    #delimit cr 

}

